@@ -100,7 +100,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
     elif os.path.exists(filepath_daq) and not os.path.exists(filepath_timestamps):  # Audio (+ annotations) only
         # if there is no video and no timestamps - generate fake from samplerate and number of samples
         # THIS SHOULD BE THE FIRST THING WE DO:
-        logging.info(f'Loading audio data:')
+        logging.info('Loading audio data:')
         if not filepath_daq_is_custom:
             basename = os.path.join(root, dat_path, datename, datename)
         else:
@@ -135,9 +135,9 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
 
     if target_sampling_rate == 0 or target_sampling_rate is None:
         resample_video_data = False
+    fps = 1 / np.mean(np.diff(ss.frames2times.y))
     if not resample_video_data:
-        logging.info(f'  setting targetsamplingrate to avg. fps.')
-        fps = 1 / np.mean(np.diff(ss.frames2times.y))
+        logging.info(f'  setting targetsamplingrate to avg. fps ({fps}).')
         target_sampling_rate = fps
 
     # LOAD TRACKS
@@ -165,7 +165,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
     with_poses = False
     poses_from = None
     if include_poses:
-        logging.info(f'Loading poses:')
+        logging.info('Loading poses:')
         poses_loader = io.get_loader(kind='poses', basename=os.path.join(root, res_path, datename, datename))
         if poses_loader:
             try:
@@ -180,13 +180,13 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                 logging.info(f'   Loading {poses_loader.path} failed.')
                 logging.exception(e)
         else:
-            logging.info(f'   Found no poses.')
+            logging.info('   Found no poses.')
         logging.info('Done.')
 
     # LOAD BALLTRACKER
     with_balltracker = False
     if include_balltracker:
-        logging.info(f'Loading ball tracker:')
+        logging.info('Loading ball tracker:')
         balltracker_loader = io.get_loader(kind='balltracks', basename=os.path.join(root, res_path, datename, datename))
         if balltracker_loader:
             try:
@@ -199,13 +199,13 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                 logging.info(f'   Loading {balltracker_loader.path} failed.')
                 logging.exception(e)
         else:
-            logging.info(f'   Found no balltracker data.')
+            logging.info('   Found no balltracker data.')
         logging.info('Done.')
 
     # LOAD MOVIEPARAMS
     with_movieparams = False
     if include_movieparams:
-        logging.info(f'Loading movie params:')
+        logging.info('Loading movie params:')
         movieparams_loader = io.get_loader(kind='movieparams', basename=os.path.join(root, dat_path, datename, datename))
         if movieparams_loader:
             try:
@@ -218,7 +218,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                 logging.info(f'   Loading {movieparams_loader.path} failed.')
                 logging.exception(e)
         else:
-            logging.info(f'   Found no movie params data.')
+            logging.info('   Found no movie params data.')
         logging.info('Done.')
 
     # Init empty audio and event data
@@ -243,7 +243,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
     manual_event_categories = {nam: cat for nam, cat in zip(event_names, event_categories)}
 
     if include_song:
-        logging.info(f'Loading automatic annotations:')
+        logging.info('Loading automatic annotations:')
         custom_filepath_annotations = filepath_annotations is not None
         if not custom_filepath_annotations:
             filepath_annotations = os.path.join(root, res_path, datename, datename)
@@ -267,7 +267,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         logging.info('Done.')
 
         # load MANUAL SONG ANNOTATIONS
-        logging.info(f'Loading manual annotations:')
+        logging.info('Loading manual annotations:')
         manual_annot_loader = io.get_loader(kind='annotations_manual', basename=filepath_annotations, basename_is_full_name=custom_filepath_annotations)
         if manual_annot_loader:
             try:
@@ -280,11 +280,11 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                 logging.exception(e)
 
         else:
-            logging.info(f'   Found no manual automatic annotations.')
+            logging.info('   Found no manual automatic annotations.')
         logging.info('Done.')
 
         # load RAW song traces
-        logging.info(f'Loading audio data:')
+        logging.info('Loading audio data:')
         if not filepath_daq_is_custom:
             basename = os.path.join(root, dat_path, datename, datename)
         else:
@@ -390,7 +390,6 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         logging.exception(e)
 
     # BODY POSITION
-    fps = None
     if pixel_size_mm is None:
         pixel_size_mm = np.nan
 
@@ -475,10 +474,11 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
 
     filepath_swap = Path(root, res_path, datename, f'{datename}_idswaps.txt')
     if fix_fly_indices and os.path.exists(filepath_swap):
-        logging.info('   applying fly identity fixes')
+        logging.info(f'   Applying fly identity fixes from {filepath_swap}.')
         try:
             indices, flies1, flies2 = ld.load_swap_indices(filepath_swap)
-            dataset = ld.swap_flies(dataset, indices, flies1=0, flies2=1)
+            dataset = ld.swap_flies(dataset, indices, flies1=flies1, flies2=flies2)
+            dataset.attrs['swap_events'] = [[ii, f1, f2] for ii, f1, f2 in zip(indices, flies1, flies2)]
             logging.info(f'  Fixed fly identities using info from {filepath_swap}.')
         except (FileNotFoundError, OSError) as e:
             logging.debug(f'  Could not load fly identities using info from {filepath_swap}.')
@@ -544,8 +544,8 @@ def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smoo
                 (relative velocities) [time,flies,flies,y/x]
     """
 
-    time = dataset.time
-    nearest_frame = dataset.nearest_frame
+    time = dataset.time.data
+    nearest_frame = dataset.nearest_frame.data
 
     sampling_rate = dataset.pose_positions.attrs['sampling_rate_Hz']
     frame_rate = dataset.pose_positions.attrs['video_fps']
@@ -610,7 +610,7 @@ def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smoo
 
         absolute = np.stack(list_absolute, axis=2)
 
-        ds_dict['abs_features'] = xr.DataArray(data=absolute,
+        ds_dict['abs_features'] = xr.DataArray(data=absolute.data,
                                                dims=['time', 'flies', 'absolute_features'],
                                                coords={'time': time,
                                                        'absolute_features': abs_feature_names,
@@ -640,7 +640,7 @@ def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smoo
         ]
 
         relative = np.stack(list_relative, axis=3)
-        ds_dict['rel_features'] = xr.DataArray(data=relative,
+        ds_dict['rel_features'] = xr.DataArray(data=relative.data,
                                                dims=['time', 'flies', 'relative_flies', 'relative_features'],
                                                coords={'time': time,
                                                        'relative_features': rel_feature_names,
